@@ -52,9 +52,15 @@
  */
 
 /*
- * $Id: config.X,v 1.99 2005/05/25 14:13:53 geoff Exp $
+ * $Id: config.X,v 1.101 2015-02-08 00:35:41-08 geoff Exp $
  *
  * $Log: config.X,v $
+ * Revision 1.101  2015-02-08 00:35:41-08  geoff
+ * Add POSIX termios support (thanks to Christian Weisgerber for the patch).
+ *
+ * Revision 1.100  2007-01-23 17:20:35-08  geoff
+ * Ignore HTML style and script tags
+ *
  * Revision 1.99  2005/05/25 14:13:53  geoff
  * Correct the spelling of the default for EXEEXT.
  *
@@ -220,6 +226,10 @@
 #include <sys/dir.h>
 #endif /* USG */
 
+#ifndef TERMIOS
+#define TERMIOS 1	/* POSIX termios.h */
+#endif /* TERMIOS */
+
 /*
 ** Things that normally go in a Makefile.  Define these just like you
 ** might in the Makefile, except you should use #define instead of
@@ -233,7 +243,7 @@
 #ifndef LINT
 #define LINT	"lint"
 #endif /* LINT */
-#define CFLAGS	"-nologo -QI0f -QIfdiv- -O2 -DWIN32=1 -I."
+#define CFLAGS	"-nologo -MT -O2 -DWIN32=1 -I."
 #ifndef LINTFLAGS
 #define LINTFLAGS ""
 #endif /* LINTFLAGS */
@@ -258,7 +268,7 @@
 ** simply doesn't support hard links.
 */
 #ifndef LINK
-#define LINK	"ln"
+#define LINK	"cp"
 #endif
 
 /*
@@ -981,7 +991,7 @@
 ** Default tags between which HTML mode ignores text
 */
 #ifndef HTMLIGNORE
-#define HTMLIGNORE	"code,samp,kbd,pre,listing,address"
+#define HTMLIGNORE	"code,samp,kbd,pre,listing,address,style,script"
 #endif
 
 /*
