@@ -1,7 +1,7 @@
 BAKEXT='.bak'
 BINDIR='c:/usr/local/bin'
 CC='cl'
-CFLAGS='-nologo -QI0f -QIfdiv- -O2 -DWIN32=1 -I.'
+CFLAGS='-nologo -MT -O2 -DWIN32=1 -I.'
 DEFHASH='english.hash'
 DEFLANG='english.aff'
 EXEEXT='.exe'
@@ -10,7 +10,7 @@ INSTALL='cp'
 LANGUAGES='{american,MASTERDICTS=american.med,HASHFILES=americanmed.hash,EXTRADICT=}'
 LIBDIR='c:/usr/local/lib'
 LIBES=''
-LINK='ln'
+LINK='cp'
 LINT='lint'
 LINTFLAGS=''
 LOOK_XREF='.IR look (1),'
@@ -27,7 +27,8 @@ REGLIB=''
 STATSUFFIX='.stat'
 SPELL_XREF='.\134\042'
 TERMLIB=''
-TIB_XREF='.IR tib \" (if available on your system)\",'
+TIB_XREF='.IR tib " (if available on your system)",'
 WORDS='c:/usr/dict/words'
 YACC='bison -y'
-case "$MAKE_SORTTMP" in "")  SORTTMP="-e /!!SORTTMP!!/s/=.*$/=/";; *) SORTTMP=;; esac
+case "$MAKE_SORTTMP" in "") \
+  SORTTMP="-e /!!SORTTMP!!/s/=.*$/=/";; *) SORTTMP=;; esac
