@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: correct.c,v 1.82 2005/04/28 14:46:51 geoff Exp $";
+    "$Id: correct.c,v 1.83 2015-02-08 00:35:41-08 geoff Exp $";
 #endif
 
 /*
@@ -48,6 +48,9 @@ static char Rcs_Id[] =
 
 /*
  * $Log: correct.c,v $
+ * Revision 1.83  2015-02-08 00:35:41-08  geoff
+ * Fix a namespace collision with "getline".
+ *
  * Revision 1.82  2005/04/28 14:46:51  geoff
  * Add code to log all corrections and replacements.
  *
@@ -256,7 +259,7 @@ static void	save_root_cap P ((ichar_t * word, ichar_t * pattern,
 		  struct flagent * sufent,
 		  ichar_t savearea[MAX_CAPS][INPUTWORDLEN + MAXAFFIXLEN],
 		  int * nsaved));
-static char *	getline P ((char * buf, int bufsize));
+static char *	get_line_from_user P ((char * buf, int bufsize));
 void		askmode P ((void));
 void		copyout P ((unsigned char ** cc, int cnt));
 static void	lookharder P ((unsigned char * string));
@@ -420,6 +423,8 @@ void checkfile ()
 
 extern char tempfile[];
 
+#define printf my_printf
+
 void correct (ctok, ctokl, itok, itokl, curchar)
     unsigned char *	ctok;
     int			ctokl;
@@ -593,7 +598,7 @@ checkagain:
 		imove (li - 1, 0);
 		cursoron();
 		(void) putchar ('!');
-		if (getline ((char *) buf, sizeof buf) == NULL)
+		if (get_line_from_user ((char *) buf, sizeof buf) == NULL)
 		    {
 		    (void) putchar (7);
 		    ierase ();
@@ -620,7 +625,7 @@ checkagain:
 		    (void) printf ("%s ", CORR_C_READONLY);
 		    }
 		(void) printf (CORR_C_REPLACE_WITH);
-		if (getline ((char *) ctok, ctokl) == NULL)
+		if (get_line_from_user ((char *) ctok, ctokl) == NULL)
 		    {
 		    (void) putchar (7);
 		    /* Put it back */
@@ -692,7 +697,7 @@ checkagain:
 		imove (li - 1, 0);
 		cursoron();
 		(void) printf (CORR_C_LOOKUP_PROMPT);
-		if (getline ((char *) buf, sizeof buf) == NULL)
+		if (get_line_from_user ((char *) buf, sizeof buf) == NULL)
 		    {
 		    (void) putchar (7);
 		    cursoroff();
@@ -1644,7 +1649,7 @@ static void save_root_cap (word, pattern, prestrip, preadd, sufstrip, sufadd,
     return;
     }
 
-static char * getline (s, len)
+static char * get_line_from_user (s, len)
     register char *	s;
     register int	len;
     {
