@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: defmt.c,v 1.62 2005/04/20 23:16:32 geoff Exp $";
+    "$Id: defmt.c,v 1.64 2015-02-08 16:09:24-08 geoff Exp $";
 #endif
 
 /*
@@ -52,7 +52,14 @@ static char Rcs_Id[] =
 
 /*
  * $Log: defmt.c,v $
- * Revision 1.62  2005/04/20 23:16:32  geoff
+ * Revision 1.64  2015-02-08 16:09:24-08  geoff
+ * When skipping curly-braced environment arguments, allow nested curlies.
+ *
+ * Revision 1.63  2015-02-08 01:28:09-08  geoff
+ * Keep track of how many dollar signs were used to enter math mode, so
+ * that we only parse the same number on exit.
+ *
+ * Revision 1.62  2005-04-20 16:16:32-07  geoff
  * Use inpossibilities to deal with the case where uppercase SS in German
  * causes ambiguities.
  *
@@ -297,6 +304,17 @@ int is_otherskip(char c)
 static int save_math_mode;
 static char save_LaTeX_Mode;
 
+/*
+ * The following variable indicates whether math mode was entered with
+ * a single or double dollar sign.  Each time math mode is entered
+ * with dollar signs, it is shifted left by one bit, and it is shifted
+ * right on math exit.  If the low-order bit is a 1, math mode was
+ * entered with a double dollar; otherwise it was entered with a
+ * single dollar.  Note that this is a kludge that breaks on illegal
+ * syntax.
+ */
+static unsigned int math_mode_dollars = 0;
+
 /*
  * The following variables are used by the deformatter to keep
  * track of keywords that may indicate text to be ignored.
@@ -946,8 +964,9 @@ static int TeX_math_end (bufp)
 
     if (**bufp == TEXDOLLAR)
 	{
-	if ((*bufp)[1] == TEXDOLLAR)
+	if ((*bufp)[1] == TEXDOLLAR  &&  (math_mode_dollars & 1) != 0)
 	    (*bufp)++;
+        math_mode_dollars >>= 1;
 	return 1;
 	}
     else if (**bufp == TEXPERCENT)
@@ -982,8 +1001,12 @@ static int TeX_math_begin (bufp)
 
     if (**bufp == TEXDOLLAR)
 	{
+        math_mode_dollars <<= 1;
 	if ((*bufp)[1] == TEXDOLLAR)
+	    {
+	    math_mode_dollars |= 1;
 	    (*bufp)++;
+            }
 	return 1;
 	}
     while (**bufp == TEXBACKSLASH && (*bufp-1==NULL || !isknj(*(*bufp-1))))
@@ -1189,16 +1212,34 @@ static int TeX_math_check (cont_char, bufp)
 static void TeX_skip_parens (bufp)
     unsigned char **	bufp;
     {
+    int                 nesting = 0;
 
-    while (**bufp  &&  **bufp != TEXRIGHTCURLY  &&  **bufp != TEXDOLLAR)
-	(*bufp)++;
+    while (**bufp)
+        {
+        if (**bufp == '\\'  &&  (*bufp)[1] != '\0')
+            (*bufp)++;
+        else if (**bufp == TEXLEFTCURLY)
+            nesting++;
+        else if (**bufp == TEXRIGHTCURLY)
+            {
+            --nesting;
+            if (nesting <= 0)
+                return;
+            }
+        (*bufp)++;
+        }
     }
 
 static void TeX_open_paren (bufp)
     unsigned char **	bufp;
     {
+
     while (**bufp  &&  **bufp != TEXLEFTCURLY  &&  **bufp != TEXDOLLAR)
-	(*bufp)++;
+	{
+	if (**bufp == '\\'  &&  (*bufp)[1] != '\0')
+            (*bufp)++;
+        (*bufp)++;
+        }
     }
 
 static void TeX_skip_check (bufp)
