@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-	"$Id: makedent.c,v 1.59 2005/04/20 23:16:32 geoff Exp $";
+	"$Id: makedent.c,v 1.60 2005/11/03 22:14:26 geoff Exp $";
 #endif
 
 /*
@@ -42,6 +42,10 @@ static char Rcs_Id[] =
 
 /*
  * $Log: makedent.c,v $
+ * Revision 1.60  2005/11/03 22:14:26  geoff
+ * When combining capitals, insert new variants at the end of the variant
+ * list.  This maintains the order of variants in the personal dictionary.
+ *
  * Revision 1.59  2005/04/20 23:16:32  geoff
  * Rename some variables to make them more meaningful.
  *
@@ -447,9 +451,10 @@ int combinecaps (hdrp, newp)
     if (retval == 0)
 	{
 	/*
-	** Couldn't combine the two entries.  Add a new variant.  For
-	** ease, we'll stick it right behind the header, rather than
-	** at the end of the list.
+	** Couldn't combine the two entries.  Add a new variant.  We
+	** stick it at the end of the variant list because it's
+	** important to maintain order; this causes the personal
+	** dictionary to have a stable ordering.
 	*/
 	forcevheader (hdrp, oldp, newp);
 	tdent = (struct dent *) mymalloc (sizeof (struct dent));
@@ -460,10 +465,13 @@ int combinecaps (hdrp, newp)
 	    return -1;
 	    }
 	*tdent = *newp;
-	tdent->next = hdrp->next;
-	hdrp->next = tdent;
-	tdent->flagfield |= (hdrp->flagfield & MOREVARIANTS);
-	hdrp->flagfield |= MOREVARIANTS;
+	for (oldp = hdrp;
+	  oldp->next != NULL  &&  oldp->flagfield & MOREVARIANTS;
+	  oldp = oldp->next)
+	    ;
+	tdent->next = oldp->next;
+	oldp->next = tdent;
+	oldp->flagfield |= MOREVARIANTS;
 	combineaffixes (hdrp, newp);
 	hdrp->flagfield |= (newp->flagfield & KEEP);
 	if (captype (newp->flagfield) == FOLLOWCASE)
